@@ -100,26 +100,7 @@ fn non_square() {
         4,
         5,
         vec![
-            62,
-            78,
-            50,
-            101,
-            82,
-            71,
-            84,
-            61,
-            73,
-            59,
-            87,
-            92,
-            111,
-            71,
-            81,
-            48,
-            64,
-            87,
-            77,
-            80,
+            62, 78, 50, 101, 82, 71, 84, 61, 73, 59, 87, 92, 111, 71, 81, 48, 64, 87, 77, 80
         ],
     );
 
